@@ -14,6 +14,9 @@
 #' @param alternative either "both", "upper" or "lower".
 #' \code{alternative} specifies if a prediction interval or
 #' an upper or a lower prediction limit should be computed
+#' @param adjust specifies if simultaneous prediction should be done for several
+#' control groups of different studies (\code{between}), or for the outcome of
+#' the current control and some treatment groups \code{within} the same trial
 #' @param alpha defines the level of confidence (\eqn{1-\alpha})
 #' @param nboot number of bootstraps
 #' @param delta_min lower start value for bisection
@@ -64,19 +67,24 @@
 #'
 #' @importFrom MASS glm.nb
 #'
-#' @references Menssen and Schaarschmidt (2022): Prediction intervals for all of M future
-#' observations based on linear random effects models. Statistica Neerlandica,
-#'  \doi{10.1111/stan.12260}
+#' @references Menssen et al. (2025): Prediction Intervals for Overdispersed Poisson
+#' Data and Their Application in Medical and Pre-Clinical Quality Control.
+#' Pharmaceutical Statistics \doi{10.1002/pst.2447}
 #'
 #' @examples
 #' # HCD from the Ames test
 #' ames_HCD
 #'
-#' # Prediction interval for one future number of revertant colonies
+#' # Pointwise prediction interval for one future number of revertant colonies
 #' # obtained in three petridishes
 #' pred_int <- neg_bin_pi(histdat=ames_HCD, newoffset=3, nboot=100)
 #' summary(pred_int)
 #'
+#' # Simultaneous prediction interval for the numbers of revertant colonies obtained in
+#' # the control and three treatment groups of a future trial
+#' pred_int_w <- neg_bin_pi(histdat=ames_HCD, newoffset=c(3, 3, 3, 3), adjust="within", nboot=100)
+#' summary(pred_int_w)
+#'
 #' # Please note that nboot was set to 100 in order to decrease computing time
 #' # of the example. For a valid analysis set nboot=10000.
 #'
@@ -84,6 +92,7 @@ neg_bin_pi <- function(histdat,
                        newdat=NULL,
                        newoffset=NULL,
                        alternative="both",
+                       adjust="within",
                        alpha=0.05,
                        nboot=10000,
                        delta_min=0.01,
@@ -240,9 +249,10 @@ neg_bin_pi <- function(histdat,
 
         # Do the bootstrap
         bs_data <- boot_predint(pred_int=pi_init,
-                                nboot=nboot)
+                                nboot=nboot,
+                                adjust=adjust)
 
-        # print("bs_data")
+        # print(bs_data)
         # print(str(bs_data))
 
         # Get bootstrapped future obs.
@@ -258,26 +268,46 @@ neg_bin_pi <- function(histdat,
         ### Define the input lists for bisection (y_star_hat_m and pred_se_m)
 
         # Fit the initial model to the bs. hist. obs
-        bs_hist_glm <- lapply(X=bs_histdat,
+        bs_hist_glm_na <- lapply(X=bs_histdat,
                               FUN=function(x){
-                                      fit <- glm(x[,1]~1,
-                                                 family=quasipoisson(link="log"),
-                                                 offset = log(x[,2]))
-                                      return(fit)
+                                      fit <- try(suppressWarnings(glm.nb(x[,1]~1 + offset(log(x[,2])))))
+
+                                      if(all(class(fit)=="try-error")){
+                                              return(NA)
+                                      }
+                                      else{
+                                              return(fit)
+                                      }
                               })
 
+        # print(bs_hist_glm_na)
+
+        # Omit all fits with convergence problems
+        bs_hist_glm <- bs_hist_glm_na[!is.na(bs_hist_glm_na)]
+
+        if((length(bs_hist_glm_na) - length(bs_hist_glm)) > 0){
+
+                n_na <- length(bs_hist_glm_na) - length(bs_hist_glm)
+                warning(paste("glm.nb could not be fit to", n_na, "bs-data sets"))
+
+        }
+
         # Get the bs Poisson mean
         bs_lambda_hat <- lapply(X=bs_hist_glm,
                                 FUN=function(x){
                                         return(exp(unname(coef(x))))
                                 })
 
-        # Get the bs dispersion parameter
-        bs_phi_hat <- lapply(X=bs_hist_glm,
+        # print(length(bs_lambda_hat))
+
+        # Get the bs dispersion parameter (kappa)
+        bs_kappa_hat <- lapply(X=bs_hist_glm,
                              FUN=function(x){
-                                     return(summary(x)$dispersion)
+                                     return(max(1/x$theta, 0.0001))
                              })
 
+        # print(length(bs_kappa_hat))
+
         # Get a vector for newoffset (if newdat is defined)
         if(!is.null(newdat)){
                 newoffset <- newdat[,2]
@@ -285,27 +315,29 @@ neg_bin_pi <- function(histdat,
 
 
         # Calculate the prediction SE
-        pred_se_fun <- function(n_star_m, phi_hat, lambda_hat, n_hist_sum){
+        pred_se_fun <- function(n_star_m, kappa_hat, lambda_hat, n_hist_mean, H){
 
-                # Variance of fut. random variable
-                var_y <- n_star_m * phi_hat * lambda_hat
+                # var for future random variable
+                var_y_star <- n_star_m * lambda_hat + kappa_hat * n_star_m^2 * lambda_hat^2
 
-                # Variance of fut. expectation
-                var_y_star_hat_m <- n_star_m^2 * phi_hat * lambda_hat * 1/n_hist_sum
-
-                # Prediction SE
-                pred_se <- sqrt(var_y + var_y_star_hat_m)
+                # var for the expected future observations
+                var_y_star_hat <- n_star_m^2 * (lambda_hat + kappa_hat * n_hist_mean * lambda_hat) / (n_hist_mean * H)
 
+                # SE for prediction
+                pred_se <- sqrt(var_y_star + var_y_star_hat)
                 return(pred_se)
         }
 
         pred_se_m_list <- mapply(FUN=pred_se_fun,
-                                 phi_hat=bs_phi_hat,
+                                 kappa_hat=bs_kappa_hat,
                                  lambda_hat=bs_lambda_hat,
                                  MoreArgs = list(n_star_m=newoffset,
-                                                 n_hist_sum=hist_n_total),
+                                                 n_hist_mean=mean(pi_init$histoffset),
+                                                 H=length(pi_init$histoffset)),
                                  SIMPLIFY=FALSE)
 
+        # print(length(pred_se_m_list))
+
         # Calculate the expected future observations
         y_star_hat_fun <- function(lambda_hat, n_star_m){
 
@@ -318,6 +350,8 @@ neg_bin_pi <- function(histdat,
                                     MoreArgs = list(n_star_m=newoffset),
                                     SIMPLIFY=FALSE)
 
+        # print(length(y_star_hat_m_list))
+
         #-----------------------------------------------------------------------
 
         ### Calculation of the calibrated quantile
@@ -327,7 +361,7 @@ neg_bin_pi <- function(histdat,
 
                 quant_calib <- bisection(y_star_hat = y_star_hat_m_list,
                                          pred_se = pred_se_m_list,
-                                         y_star = bs_y_star,
+                                         y_star = bs_y_star[1:length(y_star_hat_m_list)],
                                          alternative = alternative,
                                          quant_min = delta_min,
                                          quant_max = delta_max,
@@ -342,7 +376,7 @@ neg_bin_pi <- function(histdat,
 
                 quant_calib <- bisection(y_star_hat = y_star_hat_m_list,
                                          pred_se = pred_se_m_list,
-                                         y_star = bs_y_star,
+                                         y_star = bs_y_star[1:length(y_star_hat_m_list)],
                                          alternative = alternative,
                                          quant_min = delta_min,
                                          quant_max = delta_max,
@@ -360,7 +394,7 @@ neg_bin_pi <- function(histdat,
                 if(algorithm=="MS22"){
                         quant_calib <- bisection(y_star_hat = y_star_hat_m_list,
                                                  pred_se = pred_se_m_list,
-                                                 y_star = bs_y_star,
+                                                 y_star = bs_y_star[1:length(y_star_hat_m_list)],
                                                  alternative = alternative,
                                                  quant_min = delta_min,
                                                  quant_max = delta_max,
@@ -374,7 +408,7 @@ neg_bin_pi <- function(histdat,
                 if(algorithm=="MS22mod"){
                         quant_calib_lower <- bisection(y_star_hat = y_star_hat_m_list,
                                                        pred_se = pred_se_m_list,
-                                                       y_star = bs_y_star,
+                                                       y_star = bs_y_star[1:length(y_star_hat_m_list)],
                                                        alternative = "lower",
                                                        quant_min = delta_min,
                                                        quant_max = delta_max,
@@ -385,7 +419,7 @@ neg_bin_pi <- function(histdat,
 
                         quant_calib_upper <- bisection(y_star_hat = y_star_hat_m_list,
                                                        pred_se = pred_se_m_list,
-                                                       y_star = bs_y_star,
+                                                       y_star = bs_y_star[1:length(y_star_hat_m_list)],
                                                        alternative = "upper",
                                                        quant_min = delta_min,
                                                        quant_max = delta_max,
