@@ -18,6 +18,9 @@
 #' @param alternative either "both", "upper" or "lower".
 #' \code{alternative} specifies if a prediction interval or
 #' an upper or a lower prediction limit should be computed
+#' @param adjust specifies if simultaneous prediction should be done for several
+#' control groups of different studies (\code{between}), or for the outcome of
+#' the current control and some treatment groups \code{within} the same trial
 #' @param alpha defines the level of confidence (\eqn{1-\alpha})
 #' @param nboot number of bootstraps
 #' @param delta_min lower start value for bisection
@@ -60,9 +63,9 @@
 #' with prediction intervals or limits in the first entry (\code{$prediction}).
 #'
 #'
-#' @references Menssen and Schaarschmidt (2022): Prediction intervals for all of M future
-#' observations based on linear random effects models. Statistica Neerlandica,
-#'  \doi{10.1111/stan.12260}
+#' @references Menssen et al. (2025): Prediction Intervals for Overdispersed Poisson
+#' Data and Their Application in Medical and Pre-Clinical Quality Control.
+#' Pharmaceutical Statistics \doi{10.1002/pst.2447}
 #'
 #' @export
 #'
@@ -90,6 +93,7 @@ quasi_pois_pi <- function(histdat,
                           newdat=NULL,
                           newoffset=NULL,
                           alternative="both",
+                          adjust="within",
                           alpha=0.05,
                           nboot=10000,
                           delta_min=0.01,
@@ -246,7 +250,8 @@ quasi_pois_pi <- function(histdat,
 
         # Do the bootstrap
         bs_data <- boot_predint(pred_int=pi_init,
-                                nboot=nboot)
+                                nboot=nboot,
+                                adjust=adjust)
 
         # Get bootstrapped future obs.
         bs_futdat <- bs_data$bs_futdat
